@@ -16,8 +16,7 @@
   GNU General Public License for more details.
   
   You should have received a copy of the GNU General Public License
-  along with this program; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+  along with this program; if not, see <http://www.gnu.org/licenses/>.
 
 */
 
@@ -58,6 +57,8 @@ gyrus_admin_acl_delete_entry (GyrusAdmin *admin, const gchar *mailbox,
 		case GYRUS_IMAP_STATUS_LIST:
 		case GYRUS_IMAP_STATUS_OK:
 			break;
+		default:
+			break;
 		}
 	
 	return (status == GYRUS_IMAP_STATUS_OK);
@@ -109,6 +110,8 @@ gyrus_admin_acl_set_entry (GyrusAdmin *admin, const gchar *mailbox,
 		case GYRUS_IMAP_STATUS_LIST:
 		case GYRUS_IMAP_STATUS_OK:
 			break;
+		default:
+			break;
 		}
 	
 	return (status == GYRUS_IMAP_STATUS_OK);
@@ -162,12 +165,12 @@ gyrus_admin_acl_get (GyrusAdmin *admin, const gchar *mailbox,
 
 	}
 	else {
-		do ++iter; while (*iter != ' ' && *iter != '\n');
+		do ++iter; while (*iter != ' ' && *iter != '\r');
 		if (*iter == ' ')
 			iter ++;
 	}
 
-	if (*iter == '\n') {
+	if (*iter == '\r') {
 		g_free (msg);
 		status = gyrus_admin_listen_channel (admin, &msg, NULL);
 		g_free (msg);
@@ -210,7 +213,7 @@ gyrus_admin_acl_get (GyrusAdmin *admin, const gchar *mailbox,
 */
 		
 		list = g_list_prepend (list, entry);
-	} while (*iter2 != '\n');
+	} while (*iter2 != '\0');
 
 	/*
 	GList *l_iter;
