@@ -3,9 +3,9 @@
 
   GYRUS -- GNOME Cyrus Administrator. Administrator Mailboxes Modules.
 
-  Copyright (C) 2003-2004 Alejandro Valds Jimnez <avaldes@utalca.cl>
+  Copyright (C) 2003-2004 Alejandro Valdés Jiménez <avaldes@utalca.cl>
   Copyright (C) 2003-2004 Jorge Bustos Bustos <jbustos@utalca.cl>
-  Copyright (C) 2003-2005 Claudio Saavedra Valds <csaavedra@alumnos.utalca.cl>
+  Copyright (C) 2003-2005 Claudio Saavedra Valdés <csaavedra@alumnos.utalca.cl>
   
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -18,8 +18,7 @@
   GNU General Public License for more details.
   
   You should have received a copy of the GNU General Public License
-  along with this program; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+  along with this program; if not, see <http://www.gnu.org/licenses/>.
   
 */
 
@@ -87,8 +86,8 @@ gyrus_admin_mailbox_get_quota (GyrusAdmin *admin, const gchar *mailbox_path,
 static void
 gyrus_admin_mailbox_get_human_quota (gint quota, gchar *str_quota)
 {
-	gchar* prefix;
-	gfloat f_quota = quota;
+	const gchar* prefix;
+	gdouble f_quota = quota;
 	gint iter = 0;
      
 	while (f_quota > 1024.0 && iter < 4) {
@@ -163,7 +162,7 @@ gyrus_admin_mailbox_show_info (GyrusAdmin *admin, const gchar *user,
 	/* sets the quota info in the screen */
 	if (quota_limit < 0)
 		g_sprintf (str_quota_limit,
-			   msg);
+			   "%s", msg);
 	else
 		gyrus_admin_mailbox_get_human_quota (quota_limit,
 						     str_quota_limit);
@@ -481,7 +480,7 @@ gyrus_admin_mailbox_delete_all (GyrusAdmin *admin,
 }
 
 
-inline gboolean
+gboolean
 gyrus_admin_acl_rights_have_right (const gchar *rights,
 				   const gchar right)
 {
