@@ -3,7 +3,7 @@
 
   GYRUS -- GNOME Cyrus Administrator. Administrator Class.
   
-  Copyright (C) 2004-2005 Claudio Saavedra Valds <csaavedra@alumnos.utalca.cl>
+  Copyright (C) 2004-2005 Claudio Saavedra Valdés <csaavedra@alumnos.utalca.cl>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -16,8 +16,7 @@
   GNU General Public License for more details.
   
   You should have received a copy of the GNU General Public License
-  along with this program; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+  along with this program; if not, see <http://www.gnu.org/licenses/>.
   
 */
 
@@ -36,10 +35,7 @@
 #include "gyrus-admin-mailbox.h"
 #include "gyrus-admin-acl.h"
 
-#define GYRUS_ADMIN_GET_PRIVATE(object)                           \
-	(G_TYPE_INSTANCE_GET_PRIVATE ((object), GYRUS_TYPE_ADMIN, GyrusAdminPrivate))
-
-G_DEFINE_TYPE (GyrusAdmin, gyrus_admin, GTK_TYPE_VBOX)
+G_DEFINE_TYPE_WITH_PRIVATE (GyrusAdmin, gyrus_admin, GTK_TYPE_BOX)
 
 /* #define DEBUG_PLAIN_CHANNEL */
 
@@ -155,24 +151,17 @@ gyrus_admin_class_init (GyrusAdminClass *class)
 			       G_TYPE_NONE /* return_type */,
 			       1     /* n_params */,
 			       selection_changed_types /* param_types */);
-
-	g_type_class_add_private (class, sizeof(GyrusAdminPrivate));
 }
 
 static void
 gyrus_admin_init_get_widgets (GyrusAdmin *admin)
 {
 	GyrusAdminPrivate *priv = admin->priv;
-	gchar *file_xml;
 	GtkWidget *table;
 	GtkBuilder *builder;
 
-	file_xml = g_build_filename (GYRUS_UI_DIR, "page.xml", NULL);
-
         builder = gtk_builder_new ();
-        gtk_builder_add_from_file (builder, file_xml, NULL);
-	
-	g_free (file_xml);
+        gtk_builder_add_from_resource (builder, "/org/gnome/gyrus/page.xml", NULL);
 	
 	priv->treeview_users = GTK_TREE_VIEW (gtk_builder_get_object (builder,"treeview_users"));
 	priv->treeview_corrupt_mailbox = GTK_TREE_VIEW (gtk_builder_get_object (builder,"treeview_corrupt_mailbox"));
@@ -232,9 +221,11 @@ gyrus_admin_init_connect_signals (GyrusAdmin *admin)
 static void
 gyrus_admin_init (GyrusAdmin *admin)
 {
-	admin->priv = GYRUS_ADMIN_GET_PRIVATE (admin);
+	admin->priv = gyrus_admin_get_instance_private (admin);
 	admin->priv->session = NULL;
 	admin->priv->buffer = NULL;
+	gtk_orientable_set_orientation (GTK_ORIENTABLE (admin),
+	                                GTK_ORIENTATION_VERTICAL);
 
 	gyrus_admin_init_get_widgets (admin);
 	gyrus_admin_initialize_mailbox_tree_view (admin, FALSE);
@@ -367,7 +358,7 @@ gyrus_admin_get_users_list (GyrusAdmin *admin)
 			/* add it somewhere */
 			gtk_tree_store_append (store_corrupt, &iter_corrupt, NULL);
 			gtk_tree_store_set (store_corrupt, &iter_corrupt,
-					    COL_MAILBOX_ICON, GTK_STOCK_DIRECTORY,
+					    COL_MAILBOX_ICON, "folder",
 					    COL_MAILBOX_NAME, mb_name,
 					    -1);
 			g_strfreev (current_mailbox);
@@ -416,7 +407,7 @@ gyrus_admin_get_users_list (GyrusAdmin *admin)
 
 		if (is_valid) {
 			gtk_tree_store_set (store, &iter_child,
-					    COL_MAILBOX_ICON, GTK_STOCK_DIRECTORY,
+					    COL_MAILBOX_ICON, "folder",
 					    COL_MAILBOX_BASENAME, current_mailbox [depth],
 					    COL_MAILBOX_NAME, mb_name,
 					    -1);
@@ -425,7 +416,7 @@ gyrus_admin_get_users_list (GyrusAdmin *admin)
 		else {
 			gtk_tree_store_append (store_corrupt, &iter_corrupt, NULL);
 			gtk_tree_store_set (store_corrupt, &iter_corrupt,
-					    COL_MAILBOX_ICON, GTK_STOCK_DIRECTORY,
+					    COL_MAILBOX_ICON, "folder",
 					    COL_MAILBOX_NAME, mb_name,
 					    -1);
 		}
@@ -502,7 +493,7 @@ gyrus_admin_initialize_mailbox_tree_view (GyrusAdmin *admin,
 	              NULL);
 	
 	gtk_tree_view_column_set_attributes (column, renderer,
-	                                     "stock-id", COL_MAILBOX_ICON,
+	                                     "icon-name", COL_MAILBOX_ICON,
 	                                     NULL);
 	
 	renderer = gtk_cell_renderer_text_new ();
@@ -731,7 +722,6 @@ gyrus_admin_listen_channel (GyrusAdmin *admin, gchar **message, gint *msg_len)
 {
 	gsize bytes_read;
 	gchar **tokens = NULL;
-	GError *error = NULL;
 	GyrusImapStatus imap_status;
 
 	*message = NULL;
@@ -742,7 +732,6 @@ gyrus_admin_listen_channel (GyrusAdmin *admin, gchar **message, gint *msg_len)
 		g_free (*message);
 		g_strfreev (tokens);
 
-		error = G_IO_ERROR_NONE;
 		imap_status = GYRUS_IMAP_STATUS_OK;
 		*message = socket_readline (admin, &bytes_read);
 
@@ -783,12 +772,11 @@ gyrus_admin_write_channel (GyrusAdmin *admin, gchar *message)
 {
 	GOutputStream *stream;
 	guint msg_len;
-	gsize bytes_written;
 	GError *error = NULL;
 
 	msg_len = g_utf8_strlen (message, -1);
 	stream = g_io_stream_get_output_stream (G_IO_STREAM (admin->priv->connection));
-	bytes_written = g_output_stream_write (stream, message, msg_len, NULL, &error);
+	g_output_stream_write (stream, message, msg_len, NULL, &error);
 #ifdef DEBUG_PLAIN_CHANNEL
 	g_print ("written: %s", message);
 #endif
@@ -847,7 +835,7 @@ void
 gyrus_admin_logged_out (GyrusAdmin *admin)
 {
 	gtk_button_set_label (GTK_BUTTON (admin->priv->button_connect),
-			      GTK_STOCK_CONNECT);
+			      "gtk-connect");
 
 	gyrus_admin_clean_mailbox_treeview (GTK_TREE_VIEW (admin->priv->treeview_users), 
 					    _("Users"));
@@ -951,6 +939,8 @@ gyrus_admin_login (GyrusAdmin *admin)
 	case GYRUS_IMAP_STATUS_BYE:
 	case GYRUS_IMAP_STATUS_LIST:
 		break;
+	default:
+		break;
 	}
 	
 	return error;
@@ -1012,7 +1002,7 @@ gyrus_admin_pre_login (GyrusAdmin *admin)
 			}
 			else {
 				gtk_button_set_label (GTK_BUTTON (admin->priv->button_connect),
-						      GTK_STOCK_DISCONNECT);
+						      "gtk-disconnect");
 				gyrus_admin_post_login (admin);
 				/* correctly logged in */
 				keep_asking = FALSE;
@@ -1278,9 +1268,13 @@ gyrus_admin_on_users_selection_changed (GtkTreeSelection *selection,
 	GtkTreeModel *model;
 	gchar *mailbox_path;
 	gchar **tokens;
+	gboolean is_selected;
 	GyrusAdmin *admin = GYRUS_ADMIN (user_data);
 
-	gboolean is_selected = gtk_tree_selection_get_selected (selection, &model, &iter);
+	if (!gyrus_admin_is_connected (admin))
+	        return;
+
+	is_selected = gtk_tree_selection_get_selected (selection, &model, &iter);
 	if (is_selected)
 	{
 		gtk_tree_model_get (model, &iter,
@@ -1323,7 +1317,7 @@ gyrus_admin_on_renderer_toggled (GtkCellRendererToggle *renderer,
 	GtkTreeIter iter;
 	gboolean has_permission;
 	GtkTreeViewColumn *column;
-	gchar *permissions = "lrswipcda";
+	const gchar *permissions = "lrswipcda";
 	gchar *user;
 	gchar *perm;
 	gchar *mailbox;
@@ -1471,11 +1465,11 @@ gyrus_admin_on_acl_identifier_edited (GtkCellRendererText *cellrenderertext,
 	if (!duplicated) {
 		if (!gyrus_admin_acl_set_entry (admin, mailbox,
 						newname, rights, &error)) {
-			g_warning (error);
+			g_warning ("%s", error);
 			g_free (error);
 		} else if (!gyrus_admin_acl_delete_entry (admin, mailbox,
 							  oldname, &error)) {
-			g_warning (error);
+			g_warning ("%s", error);
 			g_free (error);
 		} else {
 			gtk_list_store_set (GTK_LIST_STORE (model), &iter,
@@ -1486,16 +1480,16 @@ gyrus_admin_on_acl_identifier_edited (GtkCellRendererText *cellrenderertext,
 		/* DELETE EXISTING ONE */
 		if (!gyrus_admin_acl_delete_entry (admin, mailbox,
 						   newname, &error)) {
-			g_warning (error);
+			g_warning ("%s", error);
 			g_free (error);
 		} else if (!gyrus_admin_acl_set_entry (admin, mailbox,
 						       newname, rights,
 						       &error)) {
-			g_warning (error);
+			g_warning ("%s", error);
 			g_free (error);
 		} else if (!gyrus_admin_acl_delete_entry (admin, mailbox,
 							  oldname, &error)) {
-			g_warning (error);
+			g_warning ("%s", error);
 			g_free (error);
 		} else {
 			/* All OK! */
