@@ -16,8 +16,7 @@
   GNU General Public License for more details.
   
   You should have received a copy of the GNU General Public License
-  along with this program; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+  along with this program; if not, see <http://www.gnu.org/licenses/>.
   
 */
 
@@ -36,7 +35,7 @@ gyrus_common_show_message (GtkWindow *parent,
 	GtkWidget *dialog;
 
 	dialog = gtk_message_dialog_new (parent, GTK_DIALOG_MODAL,
-				 type, GTK_BUTTONS_OK, message);
+				 type, GTK_BUTTONS_OK, "%s", message);
 	gtk_dialog_run (GTK_DIALOG (dialog));
 	gtk_widget_destroy (dialog);
 }
@@ -64,19 +63,14 @@ gyrus_gtk_entry_has_text (GtkEntry *entry)
 gchar *
 gyrus_dialog_password_new (void)
 {
-	gchar *file_xml;
 	GtkWidget *dialog;
 	GtkWidget *entry_password;
 	gchar *password = NULL;
 	gint result;
 	GtkBuilder *builder;
 
-	file_xml = g_build_filename (GYRUS_UI_DIR, "password.xml", NULL);
-
         builder = gtk_builder_new ();
-        gtk_builder_add_from_file (builder, file_xml, NULL);
-
-	g_free (file_xml);
+        gtk_builder_add_from_resource (builder, "/org/gnome/gyrus/password.xml", NULL);
 	
 	dialog = GTK_WIDGET (gtk_builder_get_object (builder, "dialog_password"));
 	entry_password = GTK_WIDGET (gtk_builder_get_object (builder, "entry_password"));
@@ -88,8 +82,9 @@ gyrus_dialog_password_new (void)
 		password = g_strdup (gtk_entry_get_text
 				     (GTK_ENTRY (entry_password)));
 		break;
-	case GTK_RESPONSE_CANCEL:
+	default:
 		password = NULL;
+		break;
 	}
 	gtk_widget_destroy (dialog);
 
