@@ -16,15 +16,13 @@
   GNU General Public License for more details.
   
   You should have received a copy of the GNU General Public License
-  along with this program; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+  along with this program; if not, see <http://www.gnu.org/licenses/>.
 
 */
 
 #include <config.h>
 
 #include <gtk/gtk.h>
-#include <glade/glade.h>
 #include <glib-object.h>
 #include <gdk/gdkkeysyms.h>
 #include <string.h>
@@ -36,11 +34,6 @@
 #include "gyrus-admin.h"
 #include "gyrus-admin-mailbox.h"
 
-#define GYRUS_DIALOG_FIND_MAILBOX_GET_PRIVATE(object) \
-	(G_TYPE_INSTANCE_GET_PRIVATE ((object), GYRUS_TYPE_DIALOG_FIND_MAILBOX, GyrusDialogFindMailbox))
-
-G_DEFINE_TYPE (GyrusDialogFindMailbox, gyrus_dialog_find_mailbox, GTK_TYPE_DIALOG);
-
 struct _GyrusDialogFindMailboxPrivate {
 	GtkWidget *comboboxentry_mailbox;
 
@@ -53,6 +46,9 @@ struct _GyrusDialogFindMailboxPrivate {
 	GyrusAdmin *admin;
 };
 
+G_DEFINE_TYPE_WITH_PRIVATE (GyrusDialogFindMailbox, gyrus_dialog_find_mailbox,
+                            GTK_TYPE_DIALOG);
+
 static void gyrus_dialog_find_mailbox_finalize (GObject *object);
 
 /* Callbacks */
@@ -66,10 +62,12 @@ gyrus_dialog_find_mailbox_kp (GtkWidget *widget,
 	dialog = GYRUS_DIALOG_FIND_MAILBOX (user_data);
 		
 	switch (event->keyval) {
-	case GDK_Return:
-	case GDK_KP_Enter:
+	case GDK_KEY_Return:
+	case GDK_KEY_KP_Enter:
 		gtk_button_clicked (GTK_BUTTON (dialog->priv->button_find));
 		return TRUE;
+	default:
+		break;
 	}
 	return FALSE;
 }
@@ -92,6 +90,8 @@ gyrus_dialog_find_mailbox_compare_with_method (const gchar *haystack,
 		return g_str_has_prefix (haystack, needle);
 	case GYRUS_FIND_MODE_ANY:
 		return (strstr (haystack, needle) != NULL);
+	default:
+		break;
 	}
 	return FALSE;
 }
@@ -125,9 +125,9 @@ gyrus_dialog_find_mailbox_on_button_find_clicked (GtkButton *button,
 
 	key = gtk_entry_get_text
 		(GTK_ENTRY
-		 ((GTK_BIN
+		 (gtk_bin_get_child (GTK_BIN
 		   (GYRUS_DIALOG_FIND_MAILBOX
-		    (user_data)->priv->comboboxentry_mailbox)->child)));
+		    (user_data)->priv->comboboxentry_mailbox))));
 
 	treeview = gyrus_admin_get_users_treeview (admin);
 	selection = gtk_tree_view_get_selection (treeview);
@@ -182,12 +182,13 @@ gyrus_dialog_find_mailbox_on_button_find_clicked (GtkButton *button,
 }
 
 static void
-gyrus_dialog_find_mailbox_on_entry_changed (GtkEditable *editable,
+gyrus_dialog_find_mailbox_on_entry_changed (GtkComboBox *combo_box,
 					   gpointer user_data)
 {
 	GyrusDialogFindMailbox *dialog = GYRUS_DIALOG_FIND_MAILBOX (user_data);
 	gboolean sensitive = gyrus_gtk_entry_has_text
-		(GTK_ENTRY ((GTK_BIN (dialog->priv->comboboxentry_mailbox)->child)));
+		(GTK_ENTRY (gtk_bin_get_child
+	                    (GTK_BIN (dialog->priv->comboboxentry_mailbox))));
 	gtk_widget_set_sensitive (dialog->priv->button_find, sensitive);
 }
 
@@ -200,37 +201,44 @@ gyrus_dialog_find_mailbox_class_init (GyrusDialogFindMailboxClass *class)
 
 	gyrus_dialog_find_mailbox_parent_class = g_type_class_peek_parent (class);
 	gobject_class->finalize = gyrus_dialog_find_mailbox_finalize;
-
-	g_type_class_add_private (gobject_class, sizeof (GyrusDialogFindMailboxPrivate));
 }
 
 static void
 gyrus_dialog_find_mailbox_init_get_widgets (GyrusDialogFindMailbox *dialog)
 {
-	GladeXML *xml_dialog;
-	gchar *file_glade;
 	GtkWidget *vbox_find;
+	GtkBuilder *builder;
 
-	file_glade = g_build_filename (GYRUS_GLADE_DIR, "find.glade", NULL);
-	xml_dialog = glade_xml_new (file_glade, "vbox_find", "gyrus");
-	g_free (file_glade);
+	builder = gtk_builder_new ();
+        gtk_builder_add_from_resource (builder, "/org/gnome/gyrus/find.xml", NULL);
 
-	vbox_find = glade_xml_get_widget (xml_dialog, "vbox_find");
+	vbox_find = GTK_WIDGET (gtk_builder_get_object (builder, "vbox_find"));
 	
-	gtk_container_add (GTK_CONTAINER (GTK_DIALOG (dialog)->vbox), vbox_find);
+	gtk_container_add (GTK_CONTAINER (gtk_dialog_get_content_area
+	                                  (GTK_DIALOG (dialog))), vbox_find);
 	
-	dialog->priv->button_find  = gtk_button_new_from_stock (GTK_STOCK_FIND);
-	dialog->priv->button_close = gtk_button_new_from_stock (GTK_STOCK_CLOSE);
+	dialog->priv->button_close
+	        = gtk_dialog_add_button (GTK_DIALOG (dialog), _("_Close"),
+	                                 GTK_RESPONSE_CANCEL);
+	gtk_button_set_image (GTK_BUTTON (dialog->priv->button_close),
+	                      gtk_image_new_from_icon_name ("window-close",
+	                                                    GTK_ICON_SIZE_BUTTON));
+	gtk_button_set_always_show_image (GTK_BUTTON
+	                                  (dialog->priv->button_close),
+	                                  TRUE);
+	dialog->priv->button_find
+	        = gtk_dialog_add_button (GTK_DIALOG (dialog), _("_Find"),
+	                                 GTK_RESPONSE_ACCEPT);
+	gtk_button_set_image (GTK_BUTTON (dialog->priv->button_find),
+	                      gtk_image_new_from_icon_name ("edit-find",
+	                                                    GTK_ICON_SIZE_BUTTON));
+	gtk_button_set_always_show_image (GTK_BUTTON
+	                                  (dialog->priv->button_find),
+	                                  TRUE);
 
-	gtk_box_pack_start_defaults (GTK_BOX (GTK_DIALOG (dialog)->action_area),
-				     dialog->priv->button_close);
-	gtk_box_pack_start_defaults (GTK_BOX (GTK_DIALOG (dialog)->action_area),
-				     dialog->priv->button_find);
-
-	dialog->priv->checkbutton_entire_word = glade_xml_get_widget (xml_dialog, "checkbutton_entire_word");
-	dialog->priv->checkbutton_wrap_around = glade_xml_get_widget (xml_dialog, "checkbutton_wrap_around");
-	
-	dialog->priv->comboboxentry_mailbox = glade_xml_get_widget (xml_dialog, "comboboxentry_mailbox");
+	dialog->priv->checkbutton_entire_word = GTK_WIDGET (gtk_builder_get_object (builder, "checkbutton_entire_word"));
+	dialog->priv->checkbutton_wrap_around = GTK_WIDGET (gtk_builder_get_object (builder, "checkbutton_wrap_around"));
+	dialog->priv->comboboxentry_mailbox = GTK_WIDGET (gtk_builder_get_object (builder, "comboboxentry_mailbox"));
 }
 
 static void
@@ -240,7 +248,8 @@ gyrus_dialog_find_mailbox_init_connect_signals (GyrusDialogFindMailbox *dialog)
 			  G_CALLBACK (gyrus_dialog_find_mailbox_on_button_find_clicked),
 			  dialog);
 
-	g_signal_connect (G_OBJECT (GTK_BIN (dialog->priv->comboboxentry_mailbox)->child),
+	g_signal_connect (gtk_bin_get_child
+	                  (GTK_BIN (dialog->priv->comboboxentry_mailbox)),
 			  "key-press-event", G_CALLBACK (gyrus_dialog_find_mailbox_kp), dialog);
 	
 
@@ -252,7 +261,7 @@ gyrus_dialog_find_mailbox_init_connect_signals (GyrusDialogFindMailbox *dialog)
 			  G_CALLBACK (gyrus_dialog_find_mailbox_on_checkbutton_toggled),
 			  dialog);
 */
-	g_signal_connect (G_OBJECT (GTK_BIN (dialog->priv->comboboxentry_mailbox)->child),
+	g_signal_connect (dialog->priv->comboboxentry_mailbox,
 			  "changed",
 			  G_CALLBACK (gyrus_dialog_find_mailbox_on_entry_changed),
 			  dialog);
@@ -272,6 +281,7 @@ gyrus_dialog_find_mailbox_init (GyrusDialogFindMailbox *dialog)
 
 	dialog->priv->admin = NULL;
 	
+	gtk_window_set_titlebar (GTK_WINDOW (dialog), NULL);
 	gtk_window_set_title (GTK_WINDOW (dialog), _("Find mailbox"));
 	gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
 	gtk_window_set_modal (GTK_WINDOW (dialog), TRUE);
@@ -283,7 +293,7 @@ gyrus_dialog_find_mailbox_init (GyrusDialogFindMailbox *dialog)
 	
 	gtk_combo_box_set_model (GTK_COMBO_BOX (dialog->priv->comboboxentry_mailbox),
 				 GTK_TREE_MODEL (model));
-	gtk_combo_box_entry_set_text_column (GTK_COMBO_BOX_ENTRY (dialog->priv->comboboxentry_mailbox),
+	gtk_combo_box_set_entry_text_column (GTK_COMBO_BOX (dialog->priv->comboboxentry_mailbox),
 					     0);
 	
 /*
@@ -295,7 +305,7 @@ gyrus_dialog_find_mailbox_init (GyrusDialogFindMailbox *dialog)
 				   "Foo.Bar");
 */
 
-	GTK_WIDGET_SET_FLAGS (dialog->priv->button_find, GTK_CAN_DEFAULT);
+	gtk_widget_set_can_default (dialog->priv->button_find, TRUE);
 	gtk_widget_grab_default (dialog->priv->button_find);
 
 	gtk_widget_set_sensitive (dialog->priv->button_find, FALSE);
