@@ -3,7 +3,7 @@
 
   GYRUS -- GNOME Cyrus Administrator. Dialog New Mailbox.
 
-  Copyright (C) 2004 Claudio Saavedra Valds <csaavedra@alumnos.utalca.cl>
+  Copyright (C) 2004 Claudio Saavedra Valdés <csaavedra@alumnos.utalca.cl>
   
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -16,15 +16,13 @@
   GNU General Public License for more details.
   
   You should have received a copy of the GNU General Public License
-  along with this program; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+  along with this program; if not, see <http://www.gnu.org/licenses/>.
   
 */
 
 #include <config.h>
 
 #include <gtk/gtk.h>
-#include <glade/glade.h>
 #include <glib-object.h>
 
 #include "glib/gi18n.h"
@@ -34,11 +32,6 @@
 #include "gyrus-admin.h"
 #include "gyrus-admin-mailbox.h"
 
-#define GYRUS_DIALOG_MAILBOX_NEW_PRIVATE(object) \
-	(G_TYPE_INSTANCE_GET_PRIVATE((object), GYRUS_TYPE_DIALOG_MAILBOX_NEW, GyrusDialogMailboxNew))
-
-G_DEFINE_TYPE (GyrusDialogMailboxNew, gyrus_dialog_mailbox_new, GTK_TYPE_DIALOG);
-
 struct _GyrusDialogMailboxNewPrivate {
 	GtkWidget *entry_mailbox;
 	GtkWidget *entry_quota;
@@ -52,6 +45,9 @@ struct _GyrusDialogMailboxNewPrivate {
 	GtkWidget *button_cancel;
 };
 
+G_DEFINE_TYPE_WITH_PRIVATE (GyrusDialogMailboxNew, gyrus_dialog_mailbox_new,
+                            GTK_TYPE_DIALOG);
+
 /* Callbacks */
 
 static void
@@ -68,7 +64,7 @@ gyrus_dialog_mailbox_new_on_button_ok_clicked (GtkButton *button,
 	GyrusAdmin *admin;
 
 	dialog = GYRUS_DIALOG_MAILBOX_NEW (user_data);
-	app = GYRUS_MAIN_APP (gtk_window_get_transient_for (GTK_WINDOW (dialog)));
+	app = GYRUS_MAIN_APP (g_application_get_default ());
 	
 	admin = gyrus_main_app_get_current_admin (app);
 	
@@ -153,36 +149,35 @@ static void
 gyrus_dialog_mailbox_new_class_init (GyrusDialogMailboxNewClass *class)
 {
 	gyrus_dialog_mailbox_new_parent_class = g_type_class_peek_parent (class);
-	g_type_class_add_private (class, sizeof (GyrusDialogMailboxNewPrivate));
 }
 
 static void
 gyrus_dialog_mailbox_new_init_get_widgets (GyrusDialogMailboxNew *dialog)
 {
-	GladeXML *xml_dialog;
-	gchar *file_glade;
 	GtkWidget *table;
+	GtkBuilder *builder;
 
-	file_glade = g_build_filename (GYRUS_GLADE_DIR, "create_mailbox.glade", NULL);
-	xml_dialog = glade_xml_new (file_glade, "table_dialog", "gyrus");
-	g_free (file_glade);
+        builder = gtk_builder_new ();
+        gtk_builder_add_from_resource (builder, "/org/gnome/cyrus/create_mailbox.xml", NULL);
 
-	table = glade_xml_get_widget (xml_dialog, "table_dialog");
-	gtk_container_add (GTK_CONTAINER (GTK_DIALOG (dialog)->vbox), table);
+	table = GTK_WIDGET (gtk_builder_get_object (builder, "table_dialog"));
+	gtk_container_add (GTK_CONTAINER (gtk_dialog_get_content_area
+	                                  (GTK_DIALOG (dialog))), table);
 	
-	dialog->priv->button_ok     = gtk_button_new_from_stock (GTK_STOCK_OK);
-	dialog->priv->button_cancel = gtk_button_new_from_stock (GTK_STOCK_CANCEL);
+	dialog->priv->button_cancel
+	        = gtk_dialog_add_button (GTK_DIALOG (dialog), _("_Close"),
+	                                 GTK_RESPONSE_CANCEL);
+	dialog->priv->button_ok = gtk_dialog_add_button (GTK_DIALOG (dialog),
+	                                                 _("_OK"),
+	                                                 GTK_RESPONSE_ACCEPT);
 
-	gtk_box_pack_start_defaults (GTK_BOX (GTK_DIALOG (dialog)->action_area),
-				     dialog->priv->button_cancel);
-	gtk_box_pack_start_defaults (GTK_BOX (GTK_DIALOG (dialog)->action_area),
-				     dialog->priv->button_ok);
+	dialog->priv->checkbutton_quota = GTK_WIDGET (gtk_builder_get_object (builder, "checkbutton_quota"));
+	dialog->priv->entry_mailbox = GTK_WIDGET (gtk_builder_get_object (builder, "entry_mailbox"));
+	dialog->priv->entry_quota = GTK_WIDGET (gtk_builder_get_object (builder, "entry_quota"));
+	dialog->priv->label_mailbox = GTK_WIDGET (gtk_builder_get_object (builder, "label_mailbox"));
+	dialog->priv->label_quota = GTK_WIDGET (gtk_builder_get_object (builder, "label_quota"));
 
-	dialog->priv->checkbutton_quota = glade_xml_get_widget (xml_dialog, "checkbutton_quota");
-	dialog->priv->entry_mailbox     = glade_xml_get_widget (xml_dialog, "entry_mailbox");
-	dialog->priv->entry_quota       = glade_xml_get_widget (xml_dialog, "entry_quota");
-	dialog->priv->label_mailbox     = glade_xml_get_widget (xml_dialog, "label_mailbox");
-	dialog->priv->label_quota       = glade_xml_get_widget (xml_dialog, "label_quota");
+	g_object_unref (builder);
 }
 
 static void
@@ -211,8 +206,9 @@ gyrus_dialog_mailbox_new_init_connect_signals (GyrusDialogMailboxNew *dialog)
 static void
 gyrus_dialog_mailbox_new_init (GyrusDialogMailboxNew *dialog)
 {
-	dialog->priv = g_new0 (GyrusDialogMailboxNewPrivate, 1);
+	dialog->priv = gyrus_dialog_mailbox_new_get_instance_private (dialog);
 
+	gtk_window_set_titlebar (GTK_WINDOW (dialog), NULL);
 	gtk_window_set_title (GTK_WINDOW (dialog), _("New mailbox"));
 	gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
 	gtk_window_set_modal (GTK_WINDOW (dialog), TRUE);
