@@ -3,7 +3,7 @@
 
   GYRUS -- GNOME Cyrus Administrator Main Application Class header definitions.
   
-  Copyright (C) 2004 Claudio Saavedra Valds <csaavedra@alumnos.utalca.cl>
+  Copyright (C) 2004 Claudio Saavedra Valdés <csaavedra@alumnos.utalca.cl>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -16,8 +16,7 @@
   GNU General Public License for more details.
   
   You should have received a copy of the GNU General Public License
-  along with this program; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+  along with this program; if not, see <http://www.gnu.org/licenses/>.
 */
 
 #ifdef HAVE_CONFIG_H
@@ -42,26 +41,16 @@ typedef struct _GyrusMainAppPrivate GyrusMainAppPrivate;
 typedef struct _GyrusMainApp        GyrusMainApp;
 typedef struct _GyrusMainAppClass   GyrusMainAppClass;
 
-/*** Gyrus Main Application Private Data ***/
-struct _GyrusMainAppPrivate {
-	GtkWidget *notebook;
-	GtkUIManager *ui_manager;
-	GtkActionGroup *actions_window;
-	GtkActionGroup *actions_server;
-	GtkActionGroup *actions_mailbox;
-	GtkActionGroup *actions_acl_item;
-};
-
 /*** Gyrus Main Application Data ***/
 struct _GyrusMainApp {
-	GtkWindow window;
+	GtkApplication parent_instance;
 	GyrusMainAppPrivate *priv;
 };
 
 /*** Gyrus Main Application Class Data ***/
-/*** derived from GtkWindowClass ***/
+/*** derived from GtkApplicationClass ***/
 struct _GyrusMainAppClass {
-	GtkWindowClass window_class;
+	GtkApplicationClass parent_class;
 };
 
 #include "gyrus-session.h"
@@ -76,7 +65,7 @@ Normally, you would want to run this just once.
 Returns: A new main application window.
 
 */
-GtkWidget * gyrus_main_app_new (void);
+GyrusMainApp * gyrus_main_app_new (void);
 
 /** 
     Loads a session in the main application.
