@@ -3,7 +3,7 @@
 
   GYRUS -- GNOME Cyrus Administrator.
 
-  Copyright (C) 2005 Alejandro Valds <avaldes@utalca.cl>
+  Copyright (C) 2005 Alejandro Valdés <avaldes@utalca.cl>
 
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -16,8 +16,7 @@
  GNU General Public License for more details.
  
  You should have received a copy of the GNU General Public License
- along with this program; if not, write to the Free Software
- Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ along with this program; if not, see <http://www.gnu.org/licenses/>.
 
 */
 
@@ -48,7 +47,7 @@ typedef struct _GyrusReportData {
         GtkWidget *spin_report;
         GtkTreeView *treeview_report;
 
-	gfloat font_size;
+	gdouble font_size;
 	gint lines_per_page;
 	gint num_pages;
 	gint num_lines;
@@ -75,11 +74,9 @@ static void gyrus_report_on_button_print_clicked(GtkWidget *widget, GyrusReportD
 void
 gyrus_report_show_report (GyrusAdmin *admin)
 {
-	gchar *file_xml;
 	GtkBuilder *builder;
 
 	GtkWidget *button_cancel;
-	GtkWidget *button_preview;
 	GtkWidget *button_update;
 
 	GyrusReportData *report;
@@ -88,14 +85,11 @@ gyrus_report_show_report (GyrusAdmin *admin)
 	report->mailbox_temp = NULL;
 	report->admin = admin;
 
-	file_xml = g_build_filename (GYRUS_UI_DIR, "report.xml", NULL);
-
 	builder = gtk_builder_new ();
-	gtk_builder_add_from_file (builder, file_xml, NULL);
+	gtk_builder_add_from_resource (builder, "/org/gnome/gyrus/report.xml", NULL);
 
 	report->window_report = GTK_WIDGET (gtk_builder_get_object (builder, "window-report"));
 	button_cancel = GTK_WIDGET (gtk_builder_get_object (builder, "button-cancel"));
-	button_preview = GTK_WIDGET (gtk_builder_get_object (builder, "button-preview"));
 	button_update = GTK_WIDGET (gtk_builder_get_object (builder, "button-update"));
 	report->spin_report = GTK_WIDGET (gtk_builder_get_object (builder, "spinbutton-percentage"));
 	report->treeview_report = GTK_TREE_VIEW (gtk_builder_get_object (builder,"treeview-report"));
@@ -129,7 +123,6 @@ gyrus_report_show_report (GyrusAdmin *admin)
                           report);
 	gtk_widget_show_all (report->window_report);
 
-	g_free (file_xml);
 	g_object_unref (builder);
 }
 
@@ -141,7 +134,7 @@ gyrus_report_cell_data_func (GtkTreeViewColumn *tree_column,
 			     GtkTreeIter *iter,
 			     gpointer data)
 {
-	gfloat  perc;
+	gdouble perc;
 	gchar   buf[20];
 	
 	gtk_tree_model_get(tree_model, iter, 
@@ -175,7 +168,7 @@ gyrus_report_initialize_tree_view (GtkTreeView *treeview_report)
 	              "stock-size", GTK_ICON_SIZE_LARGE_TOOLBAR,
 	              NULL);
         gtk_tree_view_column_set_attributes (column, renderer,
-					     "stock-id", COLUMN_FOLDER,
+					     "icon-name", COLUMN_FOLDER,
 					     NULL);
 	
         renderer = gtk_cell_renderer_text_new ();
@@ -362,7 +355,7 @@ gyrus_report_evaluate_quota (GtkTreeModel *model,
 				/* add user to treeview */
 				gtk_list_store_append (store, &iter_new);
 				gtk_list_store_set (store, &iter_new,
-						    COLUMN_FOLDER, GTK_STOCK_DIRECTORY,
+						    COLUMN_FOLDER, "folder",
 						    COLUMN_MAILBOX, v_mailbox[1],
 						    COLUMN_PERCENTAGE, per_user,
 						    COLUMN_QUOTA_LIMIT, quota_limit,
@@ -379,7 +372,7 @@ gyrus_report_evaluate_quota (GtkTreeModel *model,
 			/* add user to treeview */
 			gtk_list_store_append (store, &iter_new);
 			gtk_list_store_set (store, &iter_new,
-					    COLUMN_FOLDER, GTK_STOCK_DIRECTORY,
+					    COLUMN_FOLDER, "folder",
 					    COLUMN_MAILBOX, mailbox,
 					    COLUMN_PERCENTAGE, per_user,
 					    COLUMN_QUOTA_LIMIT, quota_limit,
