@@ -18,14 +18,13 @@
   GNU General Public License for more details.
   
   You should have received a copy of the GNU General Public License
-  along with this program; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+  along with this program; if not, see <http://www.gnu.org/licenses/>.
   
 */
 
 #include <config.h>
 
-#include <gconf/gconf-client.h>
+#include <gio/gio.h>
 #include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
 #include <string.h>
@@ -50,7 +49,7 @@ enum
 /* Function Prototypes */
 static void gyrus_session_add_session_to_treeview (GyrusSession *);
 static void gyrus_session_set_defaults_from_session (GyrusSession *);
-GyrusSession * gyrus_session_new_from_interface ();
+GyrusSession * gyrus_session_new_from_interface (void);
 static void gyrus_session_set_treeview (void);
 static GyrusSession * gyrus_session_get_selected_session (gboolean remove);
 static void gyrus_session_open (GyrusSession *session, gpointer user_data);
@@ -59,11 +58,9 @@ static void gyrus_session_edit_load_interface (gpointer user_data);
 void gyrus_session_load_gconf_settings (void);
 static void gyrus_session_edit_session (GyrusSession *session);
 static void gyrus_session_append_session (GyrusSession *session);
-gboolean gyrus_session_name_is_valid (GyrusSession *session);
-gboolean gyrus_session_is_valid (GyrusSession *session, gchar **why_invalid);
 static void gyrus_session_select_session (GyrusSession *session);
 
-static GConfClient *conf_client;
+static GSettings *settings = NULL;
 static GtkWidget *window = NULL;
 static GtkWidget *window_edit = NULL;
 static GtkWidget *checkbutton_secure;
@@ -136,22 +133,12 @@ gyrus_session_edit_on_button_ok_clicked (GtkWidget *widget,
 {
 	void (*GyrusSessionEditedFunc)(GyrusSession *) = user_data;
 	GyrusSession *session;
-	gchar *why_invalid;
 	session = gyrus_session_new_from_interface ();
 	
-	if (gyrus_session_is_valid (session, &why_invalid)) {
-		GyrusSessionEditedFunc (session);
-		gtk_widget_destroy (window_edit);
-		gyrus_session_select_session (session);
-		gtk_widget_grab_focus (button_open);
-	}
-	else {
-		g_print ("%s\n", why_invalid);
-		gyrus_common_show_message (GTK_WINDOW (window),
-					   GTK_MESSAGE_ERROR,
-					   why_invalid);
-		g_free (why_invalid);
-	}
+	GyrusSessionEditedFunc (session);
+	gtk_widget_destroy (window_edit);
+	gyrus_session_select_session (session);
+	gtk_widget_grab_focus (button_open);
 	gyrus_session_free (session);
 }
 
@@ -194,46 +181,53 @@ static void
 gyrus_session_on_button_delete_session_clicked (GtkWidget *widget,
 						gpointer user_data)
 {
-	gchar *host, *port, *user, *path, *sep_char, *usetls;
+	gchar *path;
 	GyrusSession *session = gyrus_session_get_selected_session (TRUE);	
+	GSettings *psettings;
+	GVariant *var, *item;
+	GVariantIter *iter;
+	GVariantBuilder builder;
+	GSList *sessions = NULL, *element;
 
-	gchar *key  = g_strconcat (PATH_KEY, "StoredSessions", NULL);
-	GSList *sessions = gconf_client_get_list (conf_client, key,
-						  GCONF_VALUE_STRING, NULL);
+	var = g_settings_get_value (settings, "stored-sessions");
+	g_variant_get (var, "as", &iter);
+	while ((item = g_variant_iter_next_value (iter)))
+	{
+	        g_variant_get (item, "s", &path);
+	        sessions = g_slist_append (sessions, g_strdup (path));
+	        g_free (path);
+	        g_variant_unref (item);
+	}
+	g_variant_iter_free (iter);
+	g_variant_unref (var);
 
-	GSList *element = g_slist_find_custom (sessions, session->name,
+	element = g_slist_find_custom (sessions, session->name,
 					       (GCompareFunc) g_ascii_strcasecmp);
 	if (element) {
 		g_free (element->data);
 		sessions = g_slist_delete_link (sessions, element);
 	}
 
-	gconf_client_set_list (conf_client, key,
-			       GCONF_VALUE_STRING, sessions,
-			       NULL);
+	g_variant_builder_init (&builder, G_VARIANT_TYPE ("as"));
+	for (element = sessions; element; element = element->next)
+	        g_variant_builder_add (&builder, "s", (gchar *) element->data);
+	g_settings_set_value (settings, "stored-sessions",
+	                      g_variant_builder_end (&builder));
 	gyrus_session_list_free (sessions);
 	
-	host = g_strconcat (PATH_SESSIONS, session->name, "/", "Host", NULL);
-	port = g_strconcat (PATH_SESSIONS, session->name, "/", "Port", NULL);
-	user = g_strconcat (PATH_SESSIONS, session->name, "/", "User", NULL);
-	usetls = g_strconcat (PATH_SESSIONS, session->name, "/", "UseTLS", NULL);
-	path = g_strconcat (PATH_SESSIONS, session->name, NULL);
-	sep_char = g_strconcat (PATH_SESSIONS, session->name, "/", "SeparatorChar", NULL);
-	
-	gconf_client_unset (conf_client, host, NULL);
-	gconf_client_unset (conf_client, port, NULL);
-	gconf_client_unset (conf_client, user, NULL);
-	gconf_client_unset (conf_client, usetls, NULL);
-	gconf_client_unset (conf_client, path, NULL);
-	gconf_client_unset (conf_client, sep_char, NULL);
-	
-	g_free (key);
+	path = g_strconcat (PATH_SESSIONS, session->name, "/", NULL);
+	psettings = g_settings_new_with_path (SCHEMA, path);
+
+	g_settings_delay (psettings);
+	g_settings_reset (psettings, "host");
+	g_settings_reset (psettings, "port");
+	g_settings_reset (psettings, "user");
+	g_settings_reset (psettings, "separator-char");
+	g_settings_reset (psettings, "use-tls");
+	g_settings_apply (psettings);
+
 	g_free (path);
-	g_free (host);
-	g_free (usetls);
-	g_free (port);
-	g_free (user);
-	g_free (sep_char);
+	g_object_unref (psettings);
 
 	gyrus_session_list_set_sensitive (FALSE);
 	gyrus_session_free (session);
@@ -283,70 +277,35 @@ gyrus_session_on_entry_changed (GtkEditable *editable,
 static void
 gyrus_session_edit_session (GyrusSession *session)
 {
-	gchar *host, *port, *user, *sep_char, *usetls;
+	gchar *path;
+	GSettings *psettings;
 	
-	host = g_strconcat (PATH_SESSIONS, session->name, "/", "Host", NULL);
-	port = g_strconcat (PATH_SESSIONS, session->name, "/", "Port", NULL);
-	user = g_strconcat (PATH_SESSIONS, session->name, "/", "User", NULL);
-	sep_char = g_strconcat (PATH_SESSIONS, session->name, "/", "SeparatorChar", NULL);
-	usetls = g_strconcat (PATH_SESSIONS, session->name, "/", "UseTLS", NULL);
-	gconf_client_set_string (conf_client, host, session->host, NULL);
-	gconf_client_set_int (conf_client, port, session->port, NULL);
-	gconf_client_set_string (conf_client, user, session->user, NULL);
-	gconf_client_set_string (conf_client, sep_char, session->sep_char, NULL);
-	gconf_client_set_bool (conf_client, usetls, session->usetls, NULL);
+	path = g_strconcat (PATH_SESSIONS, session->name, "/", NULL);
+	psettings = g_settings_new_with_path (SCHEMA, path);
 
-	g_free (host);
-	g_free (port);
-	g_free (user);
-	g_free (sep_char);
-	g_free (usetls);
+	g_settings_delay (psettings);
+	g_settings_set_string (psettings, "host", session->host);
+	g_settings_set_int (psettings, "port", session->port);
+	g_settings_set_string (psettings, "user", session->user);
+	g_settings_set_string (psettings, "separator-char", session->sep_char);
+	g_settings_set_boolean (psettings, "use-tls", session->usetls);
+	g_settings_apply (psettings);
 
-	gyrus_session_load_gconf_settings();
-}
-
-gboolean
-gyrus_session_is_valid (GyrusSession *session, gchar **why_invalid)
-{
-	gchar *host, *user, *path, *sep_char, *usetls;
-
-	gboolean is_valid;
-
-	path = g_strconcat (PATH_SESSIONS, session->name, NULL);
-	is_valid = gconf_valid_key (path, why_invalid);
 	g_free (path);
-	
-	g_return_val_if_fail (is_valid, FALSE);
-	
-	host = g_strconcat (PATH_SESSIONS, session->name, "/", "Host", NULL);
-	is_valid = gconf_valid_key (host, why_invalid);
-	g_free (host);
-	g_return_val_if_fail (is_valid, FALSE);
-
-	user = g_strconcat (PATH_SESSIONS, session->name, "/", "User", NULL);
-	is_valid = gconf_valid_key (user, why_invalid);
-	g_free (user);
-	g_return_val_if_fail (is_valid, FALSE);
-
-	sep_char = g_strconcat (PATH_SESSIONS, session->name, "/", "SeparatorChar", NULL);
-	is_valid = gconf_valid_key (sep_char, why_invalid);
-	g_free (sep_char);
-	g_return_val_if_fail (is_valid, FALSE);
-
-	usetls = g_strconcat (PATH_SESSIONS, session->name, "/", "UseTLS", NULL);
-	is_valid = gconf_valid_key (usetls, why_invalid);
-	g_free (usetls);
-
-	return is_valid;
+	g_object_unref (psettings);
+	gyrus_session_load_gconf_settings();
 }
 
 static void
 gyrus_session_append_session (GyrusSession *new)
 {
-	gchar *host, *port, *user, *sep_char, *usetls;
+	gchar *path;
 	gchar *name;
-	gchar *key;
-	GSList *sessions, *element;
+	GSList *sessions = NULL, *element;
+	GSettings *psettings;
+	GVariant *var, *item;
+	GVariantIter *iter;
+	GVariantBuilder builder;
 	
 	g_return_if_fail (new != NULL);
 
@@ -358,9 +317,17 @@ gyrus_session_append_session (GyrusSession *new)
 		return;
 	}
 	
-	key = g_strconcat (PATH_KEY, "StoredSessions", NULL);
-	sessions = gconf_client_get_list (conf_client, key,
-						  GCONF_VALUE_STRING, NULL);
+	var = g_settings_get_value (settings, "stored-sessions");
+	g_variant_get (var, "as", &iter);
+	while ((item = g_variant_iter_next_value (iter)))
+	{
+	        g_variant_get (item, "s", &name);
+	        sessions = g_slist_append (sessions, g_strdup (name));
+	        g_free (name);
+	        g_variant_unref (item);
+	}
+	g_variant_iter_free (iter);
+	g_variant_unref (var);
 
 	element = g_slist_find_custom (sessions, new->name,
 						(GCompareFunc) g_ascii_strcasecmp);
@@ -370,36 +337,33 @@ gyrus_session_append_session (GyrusSession *new)
 		gyrus_common_show_message(GTK_WINDOW (window),
 					  GTK_MESSAGE_ERROR, msg);
 		g_free (msg);
-		g_free (key);
+		gyrus_session_list_free (sessions);
 		return;
 	}
 
 	name = g_strdup (new->name);
 	sessions = g_slist_append (sessions, (gpointer) name);
 	
-	gconf_client_set_list (conf_client, key,
-			       GCONF_VALUE_STRING, sessions,
-			       NULL);
-	g_free (key);
+	g_variant_builder_init (&builder, G_VARIANT_TYPE ("as"));
+	for (element = sessions; element; element = element->next)
+	        g_variant_builder_add (&builder, "s", (gchar *) element->data);
+	g_settings_set_value (settings, "stored-sessions",
+	                      g_variant_builder_end (&builder));
 	gyrus_session_list_free (sessions);
 	
-	host = g_strconcat (PATH_SESSIONS, new->name, "/", "Host", NULL);
-	port = g_strconcat (PATH_SESSIONS, new->name, "/", "Port", NULL);
-	user = g_strconcat (PATH_SESSIONS, new->name, "/", "User", NULL);
-	sep_char = g_strconcat (PATH_SESSIONS, new->name, "/", "SeparatorChar", NULL);
-	usetls = g_strconcat (PATH_SESSIONS, new->name, "/", "UseTLS", NULL);
-	
-	gconf_client_set_string (conf_client, host, new->host, NULL);
-	gconf_client_set_int    (conf_client, port, new->port, NULL);
-	gconf_client_set_string (conf_client, user, new->user, NULL);
-	gconf_client_set_string (conf_client, sep_char, new->sep_char, NULL);
-	gconf_client_set_bool   (conf_client, usetls, new->usetls, NULL);
+	path = g_strconcat (PATH_SESSIONS, new->name, "/", NULL);
+	psettings = g_settings_new_with_path (SCHEMA, path);
 
-	g_free (host);
-	g_free (port);
-	g_free (user);
-	g_free (sep_char);
-	g_free (usetls);
+	g_settings_delay (psettings);
+	g_settings_set_string (psettings, "host", new->host);
+	g_settings_set_int (psettings, "port", new->port);
+	g_settings_set_string (psettings, "user", new->user);
+	g_settings_set_string (psettings, "separator-char", new->sep_char);
+	g_settings_set_boolean (psettings, "use-tls", new->usetls);
+	g_settings_apply (psettings);
+
+	g_free (path);
+	g_object_unref (psettings);
 	
 	gyrus_session_load_gconf_settings();
 }
@@ -458,7 +422,7 @@ gyrus_session_new_from_interface (void)
 	else
 		session->passwd = NULL;
 
-	session->sep_char = gtk_combo_box_get_active_text (GTK_COMBO_BOX (combobox_sep_char));
+	session->sep_char = gtk_combo_box_text_get_active_text (GTK_COMBO_BOX_TEXT (combobox_sep_char));
 	if (!g_utf8_strlen (session->sep_char, -1))
 		session->sep_char = g_strdup (".");
 	else if (strcmp (session->sep_char, _("Autodetect")) == 0) {
@@ -513,9 +477,11 @@ gyrus_session_treeview_on_key_press_event (GtkWidget *widget,
 		return FALSE;
 	
 	switch (event->keyval) {
-	case GDK_Delete:
+	case GDK_KEY_Delete:
 		gtk_button_clicked (GTK_BUTTON (button_delete));
 		return TRUE;
+	default:
+		break;
 	}
 	
 	return FALSE;
@@ -530,9 +496,11 @@ gyrus_session_on_key_press_event (GtkWidget *widget,
 	 key events */
 	
 	switch (event->keyval) {
-	case GDK_Escape:
+	case GDK_KEY_Escape:
 		gtk_button_clicked (GTK_BUTTON (button_cancel));
 		return TRUE;
+	default:
+		break;
 	}
 
 	return FALSE;
@@ -633,42 +601,23 @@ gyrus_session_get_selected_session (gboolean remove)
 static GyrusSession *
 gyrus_session_get_with_name (const gchar *name)
 {
-	GError *error = NULL;
 	GyrusSession *aux = NULL;
-	gchar *host;
-	gchar *port;
-	gchar *user;
-	gchar *sep_char;
-	gchar *usetls;
-	
+	GSettings *psettings;
+	gchar *path;
+
 	aux = g_new0 (GyrusSession, 1);
-	host = g_strconcat (PATH_SESSIONS, name, "/", "Host", NULL);
-	port = g_strconcat (PATH_SESSIONS, name, "/", "Port", NULL);
-	user = g_strconcat (PATH_SESSIONS, name, "/", "User", NULL);
-	sep_char = g_strconcat (PATH_SESSIONS, name, "/", "SeparatorChar", NULL);
-	usetls = g_strconcat (PATH_SESSIONS, name, "/", "UseTLS", NULL);
+	path = g_strconcat (PATH_SESSIONS, name, "/", NULL);
+	psettings = g_settings_new_with_path (SCHEMA, path);
 	
 	aux->name = g_strdup (name);
-	aux->host = gconf_client_get_string (conf_client, host, NULL);
-	aux->port = gconf_client_get_int (conf_client, port, NULL);
-	aux->user = gconf_client_get_string (conf_client, user, NULL);
-	aux->sep_char = gconf_client_get_string (conf_client, sep_char, 
-						 &error);
-	if (aux->sep_char == NULL)
-		aux->sep_char = g_strdup (".");
-	else if (error) {
-		aux->sep_char = g_strdup (".");
-		g_warning (error->message);
-		g_error_free (error);
-	}
+	aux->host = g_settings_get_string (psettings, "host");
+	aux->port = g_settings_get_int (psettings, "port");
+	aux->user = g_settings_get_string (psettings, "user");
+	aux->sep_char = g_settings_get_string (psettings, "separator-char");
+	aux->usetls = g_settings_get_boolean (psettings, "use-tls");
 
-	aux->usetls = gconf_client_get_bool (conf_client, usetls, NULL);
-
-	g_free (host);
-	g_free (port);
-	g_free (user);
-	g_free (sep_char);
-	g_free (usetls);
+	g_free (path);
+	g_object_unref (psettings);
 
 	return aux;
 }
@@ -678,15 +627,24 @@ gyrus_session_load_gconf_settings (void)
 {
 	gchar *key;
 	GyrusSession *session = NULL;
-	GSList *sessions, *aux;
+	GSList *sessions = NULL, *aux;
+	GVariant *var, *item;
+	GVariantIter *iter;
 
 	gtk_tree_view_set_model (GTK_TREE_VIEW (treeview_sessions),
 				 model_sessions);
 
-	key = g_strconcat (PATH_KEY, "StoredSessions", NULL);
-	sessions = gconf_client_get_list (conf_client, key,
-					  GCONF_VALUE_STRING, NULL);
-	g_free (key);
+	var = g_settings_get_value (settings, "stored-sessions");
+	g_variant_get (var, "as", &iter);
+	while ((item = g_variant_iter_next_value (iter)))
+	{
+	        g_variant_get (item, "s", &key);
+	        sessions = g_slist_append (sessions, g_strdup (key));
+	        g_free (key);
+	        g_variant_unref (item);
+	}
+	g_variant_iter_free (iter);
+	g_variant_unref (var);
 	
 	if (sessions != NULL)
 	{
@@ -725,16 +683,11 @@ gyrus_session_open (GyrusSession *session, gpointer user_data)
 static void
 gyrus_session_load_interface (gpointer user_data)
 {
-	gchar *file_xml;
 	GtkBuilder *builder;
-        
-	file_xml = g_build_filename (GYRUS_UI_DIR, "sessions.xml", NULL);
 
 	builder = gtk_builder_new ();
-        gtk_builder_add_from_file (builder, file_xml, NULL);
+        gtk_builder_add_from_resource (builder, "/org/gnome/gyrus/sessions.xml", NULL);
 
-	g_free (file_xml);
-	
 	window = GTK_WIDGET (gtk_builder_get_object (builder, "dialog_sessions"));
 	
 	treeview_sessions = GTK_WIDGET (gtk_builder_get_object (builder, "treeview_sessions"));
@@ -786,16 +739,11 @@ gyrus_session_load_interface (gpointer user_data)
 static void
 gyrus_session_edit_load_interface (gpointer user_data)
 {
-	gchar *file_xml;
 	GtkBuilder *builder;
 	GtkCellRenderer *cell;
         
-	file_xml = g_build_filename (GYRUS_UI_DIR, "sessions_edit.xml", NULL);
-
 	builder = gtk_builder_new ();
-        gtk_builder_add_from_file (builder, file_xml, NULL);
-
-	g_free (file_xml);
+        gtk_builder_add_from_resource (builder, "/org/gnome/gyrus/sessions_edit.xml", NULL);
 
 	window_edit = GTK_WIDGET (gtk_builder_get_object (builder, "dialog_session_edit"));
 	checkbutton_secure = GTK_WIDGET (gtk_builder_get_object (builder, "checkbutton_secure"));
@@ -857,7 +805,8 @@ gyrus_session_show_sessions (GtkWidget *widget G_GNUC_UNUSED,
 			     gpointer user_data)
 {
 	GtkTreeIter iter;
-	conf_client = gconf_client_get_default ();
+	if (!settings)
+	        settings = g_settings_new ("org.gnome.gyrus");
 	gyrus_session_load_interface (user_data);
 	gtk_window_set_modal (GTK_WINDOW (window), TRUE);
 	gyrus_session_load_gconf_settings ();
@@ -874,7 +823,6 @@ gyrus_session_show_sessions (GtkWidget *widget G_GNUC_UNUSED,
 		gtk_widget_grab_focus (button_new);
 	}
 	gtk_widget_show (window);
-	g_object_unref (G_OBJECT (conf_client));
 }
 
 static gboolean 
