@@ -1,13 +1,12 @@
 #include <string.h>
 #include <gtk/gtk.h>
-#include <glade/glade.h>
 #include <gnet.h>
 
 #include "gyrus-connection.h"
 
 #include <config.h>
 
-#define GLADE_FILE "gyrus-talk.glade"
+#define UI_FILE "gyrus-talk.xml"
 
 /* Local prototypes */
 
@@ -21,7 +20,7 @@ void response_done (void);
 void send_command (void);
 void log_append_text (const gchar *text);
 
-/* For Glade signals */
+/* For signals */
 void on_window_main_delete_event (GtkWidget *w, gpointer data);
 #ifdef HAVE_GNUTLS
 void on_checkbutton_usetls_toggled (GtkWidget *w, gpointer data);
@@ -30,7 +29,7 @@ void on_button_connect_clicked (GtkButton *b, gpointer data);
 void on_entry_cmd_activate (GtkWidget *w, gpointer data);
 void on_button_send_clicked (GtkWidget *w, gpointer data);
 
-/* Glade Widgets */
+/* Widgets */
 GtkWidget *window_main;
 
 GtkEntry *entry_host;
@@ -238,40 +237,45 @@ send_command (void)
 int
 main (int argc, char *argv[])
 {
-	GladeXML *gxml;
-
+	GtkBuilder *builder;
+	GError *error = NULL;
 	gnet_init ();
 	
 	gtk_init (&argc, &argv);
-	 
-	gxml = glade_xml_new (GLADE_FILE, NULL, NULL);
-	
-	window_main = glade_xml_get_widget (gxml, "window_main");
-	
-	entry_host = GTK_ENTRY (glade_xml_get_widget (gxml, "entry_host"));
-	checkbutton_usetls = GTK_CHECK_BUTTON (glade_xml_get_widget (gxml,
-								     "checkbutton_usetls"));
+
+	builder = gtk_builder_new ();
+	if (!gtk_builder_add_from_file (builder, UI_FILE, &error)) {
+		g_warning ("Couldn't load builder file: %s", error->message);
+		g_error_free (error);
+		error = NULL;
+		return 1;
+	}
+	window_main = GTK_WIDGET (gtk_builder_get_object (builder, "window_main"));
+
+	entry_host = GTK_ENTRY (gtk_builder_get_object (builder, "entry_host"));
+	checkbutton_usetls = GTK_CHECK_BUTTON (gtk_builder_get_object (builder,
+								       "checkbutton_usetls"));
 #ifdef HAVE_GNUTLS
 	g_signal_connect (checkbutton_usetls, "toggled",
 			  G_CALLBACK (on_checkbutton_usetls_toggled),
 			  NULL);
 #endif
-	spinbutton_port = GTK_SPIN_BUTTON (glade_xml_get_widget (gxml,
+	spinbutton_port = GTK_SPIN_BUTTON (gtk_builder_get_object (builder,
 								 "spinbutton_port"));
-	button_connect = GTK_BUTTON (glade_xml_get_widget (gxml, "button_connect"));
-	
-	textview_log = GTK_TEXT_VIEW (glade_xml_get_widget (gxml, "textview_log"));
+	button_connect = GTK_BUTTON (gtk_builder_get_object (builder, "button_connect"));
+
+	textview_log = GTK_TEXT_VIEW (gtk_builder_get_object (builder, "textview_log"));
+
+	hbox_inputs = GTK_HBOX (gtk_builder_get_object (builder, "hbox_inputs"));
+	entry_cmd = GTK_ENTRY (gtk_builder_get_object (builder, "entry_cmd"));
+
+	progressbar = GTK_PROGRESS_BAR (gtk_builder_get_object (builder, "progressbar"));
 
-	hbox_inputs = GTK_HBOX (glade_xml_get_widget (gxml, "hbox_inputs"));
-	entry_cmd = GTK_ENTRY (glade_xml_get_widget (gxml, "entry_cmd"));
-	
-	progressbar = GTK_PROGRESS_BAR (glade_xml_get_widget (gxml, "progressbar"));
-	
 	gtk_progress_bar_set_text (progressbar, "Ready");
-	
-	glade_xml_signal_autoconnect (gxml);
-	
-	g_object_unref (G_OBJECT (gxml));
+
+	gtk_builder_connect_signals (builder, NULL);
+
+	g_object_unref (G_OBJECT (builder));
 
 	gtk_widget_show_all (window_main);
 #ifndef HAVE_GNUTLS
